/* Developed for Lenovo Educational Board Pass 2
   © Lenovo Created by Joshua Grosser
   v. 1.0 */

// include the following libraries
#include <Wire.h>
#include <SparkFun_APDS9960.h>
#include <Adafruit_NeoPixel.h>

#define NEOPIXEL_PIN 45 // Neopixel is on pin 45
#define NEOPIXEL_COUNT 1 // There is only 1 RGB LED on DOS
#define NEOPIXEL_INDEX 0 // RGB LED is at index 0
#define DELAYVAL 500 // Time (in milliseconds) to pause between pixels
uint16_t ambient_light = 0;

// Create objects
Adafruit_NeoPixel Pixel(NEOPIXEL_COUNT, NEOPIXEL_PIN, NEO_GRB + NEO_KHZ800);
SparkFun_APDS9960 apds = SparkFun_APDS9960();

void setup() {
  // Initialize Serial port
  Serial.begin(9600);
  Serial.println();
  
  // Initialize APDS
  apds.init();
  apds.enableLightSensor(false);
  // Wait for initialization and calibration to finish
  delay(500);
  
  // initialize Neopixel
  Pixel.begin();

  // Set all pixel colors to OFF
  Pixel.clear();
  Pixel.show();
}

void loop() {
  // Read the light levels (ambient)
  apds.readAmbientLight(ambient_light);
  // if statements to turn Neopixel brightness
  // based on ambient light values
  if (ambient_light < 15)
  {
    Pixel.setPixelColor(NEOPIXEL_INDEX, 255, 255, 255);
    Pixel.show();
  }
  else if (ambient_light >= 15 && ambient_light < 30)
  {
    Pixel.setPixelColor(NEOPIXEL_INDEX, 250, 250, 250);
    Pixel.show();
  }
  else if (ambient_light >= 30 && ambient_light < 50)
  {
    Pixel.setPixelColor(NEOPIXEL_INDEX, 245, 245, 245);
    Pixel.show();
  }
  else if (ambient_light >= 50 && ambient_light < 75)
  {
    Pixel.setPixelColor(NEOPIXEL_INDEX, 235, 235, 235);
    Pixel.show();
  }
  else if (ambient_light >= 75 && ambient_light < 100)
  {
    Pixel.setPixelColor(NEOPIXEL_INDEX, 220, 220, 220);
    Pixel.show();
  }
  else if (ambient_light >= 100 && ambient_light < 200)
  {
    Pixel.setPixelColor(NEOPIXEL_INDEX, 190, 190, 190);
    Pixel.show();
  }
  else if (ambient_light >= 200 && ambient_light < 1000)
  {
    Pixel.setPixelColor(NEOPIXEL_INDEX, 100, 100, 100);
    Pixel.show();
  }
  else if (ambient_light >= 1000 && ambient_light < 3000)
  {
    Pixel.setPixelColor(NEOPIXEL_INDEX, 50, 50, 50);
    Pixel.show();
  }
  else if (ambient_light >= 3000 && ambient_light < 5000)
  {
    Pixel.setPixelColor(NEOPIXEL_INDEX, 25, 25, 25);
    Pixel.show();
  }
  else
  {
    Pixel.setPixelColor(NEOPIXEL_INDEX, 0, 0, 0);
    Pixel.show();
  }
}
